function [utip]=circular_hole_had
    % Parameters:
    E=7000;
    nu=0.3;
    graphics=1;
    Plot_errors=0;
    L= 360; % Length of the plate
    W = 10; % Thickness of the plate
    H = 200; % Width
    R= 100;
    magn=100;
    fs={['curve 1 line ' num2str(R) '  0 ' num2str(H) ' 0'],...
        ['curve 2 line ' num2str(H) ' 0 ' num2str(H) ' ' num2str(L)],...
        ['curve 3 line ' num2str(H) ' ' num2str(L) ' 0 ' num2str(L)],...
        ['curve 4 line ' num2str(0) ' ' num2str(L) ' ' num2str(0) ' ' num2str(R)],...
        ['curve 5 arc  0 ' num2str(R) ' ' num2str(R) '  0  center 0 0'],...
        ['subregion 1  property 1 boundary  1  2 3 4 5']
        };
    utip=[];
    Targetnel=  500;
    
    
    [fens,gcells,groups,edge_gcells,edge_groups]=targe2_mesher(cat(2,fs,{['m-ctl-point constant ' num2str(R/4)]}), 1.0);
    
    for Adapt=1:5
        
        length(gcells)
        %             mesh{1}=fens;
        %             mesh{2}=gcells;
        %             drawmesh(mesh); view(2); pause (1)
        %     Material
        prop = property_linel_iso (struct('E',E,'nu',nu));
        mater = mater_defor_ss_linel_biax (struct('property',prop, ...
            'reduction','stress'));
        % Finite element block
        feb = feblock_defor_ss(struct ('mater',mater, 'gcells',gcells, 'integration_rule',tri_rule(1)));
        % Geometry
        geom = field(struct ('name',['geom'], 'dim', 2, 'fens',fens));
        % Define the displacement field
        u   = clone(geom,'u');
        u   = u*0; % zero outfunction five
        % Apply EBC's
        % Apply EBC's
        ebc_fenids=fenode_select (fens,struct('box',[0,0,-Inf,Inf],'inflate',1/1000));
        ebc_prescribed=ones(1,length (ebc_fenids));
        ebc_comp=ones(1,length (ebc_fenids))*1;
        ebc_val=ebc_fenids*0;
        u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
        ebc_fenids=fenode_select (fens,struct('box',[-Inf,Inf,0,0],'inflate',1/1000));
        ebc_prescribed=ones(1,length (ebc_fenids));
        ebc_comp=ones(1,length (ebc_fenids))*2;
        ebc_val=ebc_fenids*0;
        u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
        u   = apply_ebc (u);
        % Number equations
        u   = numbereqns (u);
        % Assemble the system matrix
        K = start (sparse_sysmat, get(u, 'neqns'));
        K = assemble (K, stiffness(feb, geom, u));
        % Load
        F = sysvec;
        F = start (F, get(u, 'neqns'));
        tol=0.001*R;
        bdry_gcells = mesh_bdry(gcells, []);
        bcl = gcell_select(fens, bdry_gcells, ...
            struct ('box',[-Inf,Inf,L,L],'inflate',tol));
        lfeb = feblock_defor_ss(struct ('mater',mater, 'gcells',bdry_gcells(bcl),...
            'integration_rule',gauss_rule(1,2)));
        fi= force_intensity(struct ('magn',[0;magn]));
        F = assemble (F, distrib_loads(lfeb, geom, u, fi,2));
        % Solve
        u = scatter_sysvec(u, K\F);
        nl=fenode_select (fens,struct ('box',[48,48,52,52],'inflate',100*tol));
        theutip=gather(u,nl,'values');
        disp (['displacement =' num2str(theutip(2))])
        utip =[utip theutip(2)];
        
        nodal_stress = field_from_integration_points_spr(feb, geom, u, [], 'Cauchy', 1:3);
        errors = error_elementwise (feb, geom, u, [], nodal_stress);
        elerrs=sqrt(sum(errors));
        targeterr=sqrt(sum(elerrs.^2)/Targetnel);
        
        x=zeros(length(fens),2);
        for j=1:length(fens)
            x(j,:)=get(fens(j),'xyz');
        end
        hcurs=zeros(length(fens),1)+Inf;
        hests=zeros(length(fens),1)+Inf;
        for j=1:length(gcells)
            conn=get(gcells(j),'conn');
            V=x(conn(2),:)-x(conn(1),:);
            W=x(conn(3),:)-x(conn(1),:);
            A=(V(1)*W(2)-V(2)*W(1))/2;
            hcur=sqrt(A*4/sqrt(3));
            errcur=elerrs(j);
            hest=hcur*(targeterr/errcur);
            for k=1:length(conn)
                hcurs(conn(k))=min([hcurs(conn(k)),hcur]);
                hests(conn(k))=min([hests(conn(k)),hest]);
            end
        end
        
        % Plot
        if graphics
            %             Plot errors
            if (Plot_errors)
                gv=graphic_viewer;
                gv=reset (gv,struct('limits', 1.1*[0,H,0,L]));
                cmap=cadcolors;
                nvals=sqrt(sum(errors));
                dcm=data_colormap(struct ('range',[min(nvals),max(nvals)], 'colormap',cmap));%[min(nvals),max(nvals)]
                for i=1:length(gcells)
                    color = map_data (dcm, nvals(i));
                    draw(gcells(i), gv, struct ('x',geom,'u', u, 'facecolor',color));
                end
                view (2)
                lighting  none;
                nvalsrange=[min(nvals),max(nvals)];
                cbh=colorbar;
                set(cbh,...
                    'Position',[0.8 0.15 0.05 0.7],...
                    'YLim',[0,1],...
                    'YTick',[0,1],...
                    'YTickLabel',{[num2str(nvalsrange(1))],[num2str(nvalsrange(2))]});%{[num2str((min(nvals)))],[num2str((max(nvals)))]}
                set(get(cbh,'XLabel'),'String',['Error']);
            else
                %             Plots stresses
                sigj=3;
                gv=graphic_viewer;
                gv=reset (gv,struct('limits', 1.1*[0,H,0,L]));
                cmap=jet;
                fld = field_from_integration_points_spr(feb, geom, u, [], 'Cauchy', sigj);
                nvals=get(fld,'values');
                dcm=data_colormap(struct ('range',[min(nvals),max(nvals)], 'colormap',cmap));%[min(nvals),max(nvals)]
                colorfield=field(struct ('name', ['colorfield'], 'data',map_data(dcm, nvals)));
                draw(feb, gv, struct ('x',geom,'u', u, 'colorfield',colorfield, 'shrink',1));
                lighting  none;
                title (['Stress']);
                colormap(cmap);
                cbh=colorbar;
                set(cbh,...
                    'Position',[0.76 0.15 0.1 0.7],...
                    'YLim',[0,1],...
                    'YTick',[0,1],...
                    'YTickLabel',{[num2str((min(nvals)))],[num2str((max(nvals)))]});%{[num2str((min(nvals)))],[num2str((max(nvals)))]}
                set(get(cbh,'XLabel'),'String',['\sigma_{' num2str(sigj) '}']);
                view (2)
            end
        end
        
        [fens,gcells,groups,edge_gcells,edge_groups] = targe2_mesher_adapt(cat(2,fs,{['m-ctl-point constant ' num2str(min(hests)/100)]}),hcurs,hests,x, 1.0);
        
    end
end